@@ -3,6 +3,7 @@ from pathlib import Path
 
 import click
 
+from kks.ejudge import Links
 from kks.util.common import format_file
 from kks.util.h2t import HTML2Text
 from kks.util.storage import Config
@@ -15,7 +16,7 @@ def convert(force, files):
     """Convert statements from HTML to Markdown (e.g. kr statements copied by scp)"""
 
     md_width = Config().options.mdwidth
-    converter = HTML2Text(bodywidth=md_width, baseurl='https://caos.ejudge.ru/ej/client')  # NOTE baseurl may be incorrect
+    converter = HTML2Text(bodywidth=md_width, baseurl=Links.WEB_CLIENT_ROOT)  # NOTE baseurl may be incorrect
     converter.pad_tables = True
 
     for filename in files:
