@@ -1,34 +1,29 @@
-import configparser
 import difflib
 import pickle
+from abc import ABCMeta
+from functools import wraps
 from pathlib import Path
+from time import time, sleep
 
 import click
 
 from kks.ejudge import AuthData
 
 
+class Singleton(ABCMeta):
+    _instances = {}
+    def __call__(cls, *args, **kwargs):
+        if cls not in cls._instances:
+            cls._instances[cls] = super(Singleton, cls).__call__(*args, **kwargs)
+        return cls._instances[cls]
+
+
 def config_directory():
     directory = Path(click.get_app_dir('kks', force_posix=True))
     directory.mkdir(exist_ok=True)
     return directory
 
 
-def read_config():
-    config = configparser.ConfigParser()
-    config.optionxform = str
-    cfg = config_directory() / 'config.ini'
-    if cfg.is_file():
-        config.read(cfg)
-    return config
-
-
-def write_config(config):
-    cfg = config_directory() / 'config.ini'
-    with cfg.open('w') as f:
-        config.write(f)
-
-
 def get_clang_style_string():
     cfg = config_directory() / '.clang-format'
     if cfg.exists():
@@ -208,3 +203,32 @@ def find_problem_rootdir():
     if len(parts) < 2:
         return None
     return rootdir / parts[0] / parts[1]
+
+
+def with_retries(delay=0.5, multiplier=1.5, step=1, timeout=10):
+    def decorator(func):
+        initial_delay = delay
+
+        @wraps(func)
+        def wrapper(*args, **kwargs):
+            delay = initial_delay
+            overall_start = time()
+            iteration = 1
+            while True:
+                start = time()
+                result = func(*args, **kwargs)
+                if result is not None:
+                    return result
+                elapsed = time() - start
+
+                if time() - overall_start > timeout:
+                    return None
+
+                sleep(max(0, delay - elapsed))
+                if iteration % step == 0:
+                    delay *= multiplier
+                iteration += 1
+
+        return wrapper
+
+    return decorator
